# jsonclasses-pymongo
JSON Classes integration with Pymongo.

## Prerequisites

To use this package, you should have `jsonclasses` and `pymongo` installed.

## Installation

Install `jsonclasses-pymongo` with `pip`.

```sh
pip install jsonclasses-pymongo
```

## Documentation

Read on bla bla bla.

## License

[MIT License](https://github.com/WiosoftCrafts/jsonclasses-pymongo/blob/master/LICENSE)
